%define anolis_release 3
Name:           multipath-tools
Version:        0.9.5
Release:        %{anolis_release}%{?dist}
Summary:        Tools to manage multipath devices using multipath-tool

License:        GPLv2
URL:            http://christophe.varoqui.free.fr/
Source0:        https://github.com/opensvc/multipath-tools/archive/%{version}.tar.gz
Source1:        multipath.conf

BuildRequires:  libaio-devel, device-mapper-devel >= 1.02.89
BuildRequires:  libselinux-devel, libsepol-devel
BuildRequires:  readline-devel, ncurses-devel
BuildRequires:  systemd-units, systemd-devel
BuildRequires:  json-c-devel, perl-interpreter, pkgconfig, gcc
BuildRequires:  userspace-rcu-devel
BuildRequires:  libmount-devel
BuildRequires:  make

Requires: %{name}-libs = %{version}-%{release}
Requires: kpartx = %{version}-%{release}
Requires: device-mapper >= 1.02.96
Requires: libmount
Requires: readline
Requires: userspace-rcu
Requires(post): systemd-units
Requires(preun): systemd-units
Requires(postun): systemd-units
Provides:         device-mapper-multipath

%description
%{name} provides tools to manage multipath devices by
instructing the device-mapper multipath kernel module what to do.
The tools are :
* multipath - Scan the system for multipath devices and assemble them.
* multipathd - Detects when paths fail and execs multipath to update things.

%package libs
Summary: The %{name} modules and shared library
# only libmpathcmd is LGPLv2+
License: GPLv2 and LGPLv2+
Provides:         device-mapper-multipath-libs

%description libs
The %{name}-libs provides the path checker
and prioritizer modules. It also contains the libmpathpersist and
libmpathcmd shared libraries, as well as multipath's internal library,
libmultipath.

%package devel
Summary: Development libraries and headers for %{name}
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Provides:         device-mapper-multipath-devel

%description devel
This package contains the files need to develop applications that use
multipath-tool's lbmpathpersist and libmpathcmd libraries.

%package -n kpartx
Summary: Partition device manager for device-mapper devices

%description -n kpartx
kpartx manages partition creation and removal for device-mapper devices.

%package -n libdmmp
Summary: multipath-tool C API library
License: GPLv3+
Requires: json-c
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description -n libdmmp
This package contains the shared library for the multipath-tool
C API library.

%package -n libdmmp-devel
Summary: multipath-tool C API library headers
Requires: pkgconfig
Requires: libdmmp = %{version}-%{release}

%description -n libdmmp-devel
This package contains the files needed to develop applications that use
multipath-tool's libdmmp C API library

%prep
%autosetup -n multipath-tools-%{version} -p1
sed -i "s/echo \"-D_FORTIFY_SOURCE=3\"/echo \"-D_FORTIFY_SOURCE=2\"/g" create-config.mk
cp %{SOURCE1} .

%build
%define _sbindir /usr/sbin
%define _libdir /usr/%{_lib}
#%define _udevdir /usr/lib/udev
%define _libmpathdir /%{_lib}/multipath
%define _pkgconfdir %{_libdir}/pkgconfig
%make_build LIB=%{_lib}

%install
rm -rf $RPM_BUILD_ROOT
%make_install \
        bindir=%{_sbindir} \
        syslibdir=%{_libdir} \
        usrlibdir=%{_libdir} \
        libdir=%{_libmpathdir} \
        rcdir=%{_initrddir} \
        unitdir=%{_unitdir} \
        includedir=%{_includedir} \
        pkgconfdir=%{_pkgconfdir} \
	tmpfilesdir=%{_tmpfilesdir}

install -d %{buildroot}/etc/multipath
rm -rf %{buildroot}/%{_initrddir}

%generate_compatibility_deps

%post
%systemd_post multipathd.service

%preun
%systemd_preun multipathd.service

%postun
if [ $1 -ge 1 ] ; then
        /sbin/multipathd forcequeueing daemon > /dev/null 2>&1 || :
fi
%systemd_postun_with_restart multipathd.service

%triggerun -- %{name} < 0.4.9-37
# make sure old systemd symlinks are removed after changing the [Install]
# section in multipathd.service from multi-user.target to sysinit.target
/bin/systemctl --quiet is-enabled multipathd.service >/dev/null 2>&1 && /bin/systemctl reenable multipathd.service ||:

%files
%license LICENSES/GPL-2.0 LICENSES/LGPL-2.0 LICENSES/GPL-3.0
%{_sbindir}/multipath
%{_sbindir}/multipathd
%{_sbindir}/multipathc
%{_sbindir}/mpathpersist
/lib64/multipath/libcheck*.so
/lib64/multipath/libprio*.so
/lib64/multipath/libforeign-nvme.so
%{_unitdir}/multipathd.service
%{_unitdir}/multipathd.socket
/share/man/man5/multipath.conf.5*
/share/man/man8/multipath.8*
/share/man/man8/multipathd.8*
/share/man/man8/multipathc.8*
/share/man/man8/mpathpersist.8*
%config %{_udevrulesdir}/56-multipath.rules
%config %{_udevrulesdir}/11-dm-mpath.rules
%dir /usr/lib/modules-load.d
/usr/lib/modules-load.d/multipath.conf
%{_tmpfilesdir}/multipath.conf
%doc README.md
%doc multipath.conf
%dir /etc/multipath
%{abidir}/multipath-option.list
%{abidir}/libcheck*.dump
%{abidir}/libprio*.dump
%{abidir}/libforeign-nvme.dump

%files libs
%dir %{abidir}
%license LICENSES/GPL-2.0 LICENSES/LGPL-2.0 LICENSES/LGPL-2.1
%doc README.md
%{_libdir}/libmultipath.so
%{_libdir}/libmultipath.so.*
%{_libdir}/libmpathutil.so
%{_libdir}/libmpathutil.so.*
%{_libdir}/libmpathpersist.so.*
%{_libdir}/libmpathcmd.so.*
%{_libdir}/libmpathvalid.so.*
%{abidir}/libmultipath.dump
%{abidir}/libmpathpersist.dump
%{abidir}/libmpathcmd.dump
%{abidir}/libmpathvalid.dump
%{abidir}/libmpathutil.dump
%{_libmpathdir}/*

%ldconfig_scriptlets libs

%files devel
%doc README.md
%{_libdir}/libmpathpersist.so
%{_libdir}/libmpathcmd.so
%{_libdir}/libmpathvalid.so
%{_includedir}/mpath_cmd.h
%{_includedir}/mpath_persist.h
%{_includedir}/mpath_valid.h
/share/man/man3/mpath_persistent_reserve_in.3*
/share/man/man3/mpath_persistent_reserve_out.3*

%files -n kpartx
%license LICENSES/GPL-2.0
%doc README.md
%{_sbindir}/kpartx
%{_udevdir}/kpartx_id
/share/man/man8/kpartx.8*
%config %{_udevrulesdir}/11-dm-parts.rules
%config %{_udevrulesdir}/66-kpartx.rules
%config %{_udevrulesdir}/68-del-part-nodes.rules

%files -n libdmmp
%license LICENSES/GPL-3.0
%doc README.md
%{_libdir}/libdmmp.so.*
%{abidir}/libdmmp.dump

%ldconfig_scriptlets -n libdmmp

%files -n libdmmp-devel
%doc README.md
%{_libdir}/libdmmp.so
%dir %{_includedir}/libdmmp
%{_includedir}/libdmmp/*
/share/man/man3/dmmp_*
/share/man/man3/libdmmp.h.3*
%{_pkgconfdir}/libdmmp.pc

%changelog
* Thu Apr 11 2024 Chang Gao <gc-taifu@linux.alibaba.com> - 0.9.5-3
- Add missing provides after change the package name

* Mon Apr 8 2024 Wenlong Zhang <zhangwenlong@loongson.cn> - 0.9.5-2
- delete multipathd-option.list device-mapper-multipath

* Wed  Mar 13 2024 Kaiqiang Wang <wangkaiqiang@inspur.com> - 0.9.5-1
- update to 0.9.5

* Fri Mar 08 2024 Kaiqiang Wang <wangkaiqiang@inspur.com> - 0.9.4-2
- modify device-mapper-multipath to multipath-tools

* Sat May 06 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.9.4-1
- rebuild with libaio update

* Thu Nov 03 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.8.8-2
- optimise spec file

* Mon Mar 14 2022 forrest_ly <flin@linux.alibaba.com> - 0.8.8-1
- Init for Anolis OS 23
